@@ -31,10 +31,10 @@
 G_BEGIN_DECLS
 
 char *netstatus_sysdeps_read_iface_statistics       (const char *iface,
-						     long       *in_packets,
-						     long       *out_packets,
-						     long       *in_bytes,
-						     long       *out_bytes);
+						     gulong     *in_packets,
+						     gulong     *out_packets,
+						     gulong     *in_bytes,
+						     gulong     *out_bytes);
 char *netstatus_sysdeps_read_iface_wireless_details (const char *iface,
 						     gboolean   *is_wireless,
 						     int        *signal_strength);
